@@ -1147,7 +1147,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                 }
                 else {
                   if (isalnum(*char_ptr)) {
-                    SPVM_COMPILER_error(compiler, "Invalid escape character in string literal %c at %s line %d\n", *char_ptr, compiler->cur_file, compiler->cur_line);
+                    SPVM_COMPILER_error(compiler, "Invalid escape character in string literal \"\\%c\" at %s line %d\n", *char_ptr, compiler->cur_file, compiler->cur_line);
                   }
                   else {
                     str[str_length] = '\\';
